# remodels

[![PyPI](https://img.shields.io/pypi/v/remodels.svg)][pypi_]
[![Status](https://img.shields.io/pypi/status/remodels.svg)][status]
[![Python Version](https://img.shields.io/pypi/pyversions/remodels)][python version]
[![License](https://img.shields.io/pypi/l/remodels)][license]

[![Documentation Status](https://readthedocs.org/projects/remodels/badge/?version=latest)][read the docs]
[![Tests](https://github.com/zakrzewow/remodels/workflows/Tests/badge.svg)][tests]
[![Codecov](https://codecov.io/gh/zakrzewow/remodels/branch/main/graph/badge.svg)][codecov]

[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)][pre-commit]
[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)][black]

[pypi_]: https://pypi.org/project/remodels/
[status]: https://pypi.org/project/remodels/
[python version]: https://pypi.org/project/remodels
[read the docs]: https://remodels.readthedocs.io/en/latest/
[tests]: https://github.com/zakrzewow/remodels/actions?workflow=Tests
[codecov]: https://app.codecov.io/gh/zakrzewow/remodels
[pre-commit]: https://github.com/pre-commit/pre-commit
[black]: https://github.com/psf/black

<!-- ## Installation

You can install _remodels_ via [pip] from [PyPI]:

```console
$ pip install remodels
``` -->

## Usage

Please see the [Usage] for details.

## License

Distributed under the terms of the [MIT license][license],
_remodels_ is free and open source software.

## Credits

This project was generated from [@cjolowicz]'s [Hypermodern Python Cookiecutter] template.

[@cjolowicz]: https://github.com/cjolowicz
[pypi]: https://pypi.org/
[hypermodern python cookiecutter]: https://github.com/cjolowicz/cookiecutter-hypermodern-python
[pip]: https://pip.pypa.io/

<!-- github-only -->

[license]: https://github.com/zakrzewow/remodels/blob/main/LICENSE
[usage]: https://remodels.readthedocs.io/en/latest/usage.html
